<?php
/**
 * Post carousel widgets
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Multidirectory_Addon_Widget_Post_Carousel extends Widget_Base {

	public function get_name() {
		return 'multidirectory-addon-post-carousel';
	}

	public function get_title() {
		return esc_html__( 'Post Carousel', 'multidirectory-addon' );
	}

	public function get_icon() {
		return 'eicon-slider-push';
	}

	public function get_keywords() {
		return [ 'blog', 'post', 'carousel' ];
	}

	public function get_categories() {
		return [ 'Multidirectory_Addon_elements' ];
	}

	public function get_script_depends() {
		return [ 'owl-carousel', 'post-carousel' ];
	}

	public function get_style_depends() {
		return [ 'owl-carousel', 'owl-carousel-theme' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'post_carousel',
			[
				'label' => esc_html__( 'Post Carousel', 'multidirectory-addon' ),
			]
		);

		$this->add_control(
			'count',
			[
				'label'         => esc_html__( 'Posts Per Page', 'multidirectory-addon' ),
				'description'   => esc_html__( 'You can enter "-1" to display all items.', 'multidirectory-addon' ),
				'type'          => Controls_Manager::TEXT,
				'default'       => '6',
				'label_block'   => true,
			]
		);

		$this->add_control(
			'order',
			[
				'label'         => esc_html__( 'Order', 'multidirectory-addon' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''          => esc_html__( 'Default', 'multidirectory-addon' ),
					'DESC'      => esc_html__( 'DESC', 'multidirectory-addon' ),
					'ASC'       => esc_html__( 'ASC', 'multidirectory-addon' ),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'         => esc_html__( 'Order By', 'multidirectory-addon' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''              => esc_html__( 'Default', 'multidirectory-addon' ),
					'date'          => esc_html__( 'Date', 'multidirectory-addon' ),
					'title'         => esc_html__( 'Title', 'multidirectory-addon' ),
					'name'          => esc_html__( 'Name', 'multidirectory-addon' ),
					'modified'      => esc_html__( 'Modified', 'multidirectory-addon' ),
					'author'        => esc_html__( 'Author', 'multidirectory-addon' ),
					'rand'          => esc_html__( 'Random', 'multidirectory-addon' ),
					'ID'            => esc_html__( 'ID', 'multidirectory-addon' ),
					'comment_count' => esc_html__( 'Comment Count', 'multidirectory-addon' ),
					'menu_order'    => esc_html__( 'Menu Order', 'multidirectory-addon' ),
				],
			]
		);

		$this->add_control(
			'include_categories',
			[
				'label' 		=> __( 'Include Categories', 'multidirectory-addon' ),
				'description' 	=> __( 'Enter the categories slugs seperated by a "comma"', 'multidirectory-addon' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'exclude_categories',
			[
				'label' 		=> __( 'Exclude Categories', 'multidirectory-addon' ),
				'description' 	=> __( 'Enter the categories slugs seperated by a "comma"', 'multidirectory-addon' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'include_tags',
			[
				'label'         => esc_html__( 'Include Tags', 'multidirectory-addon' ),
				'description'   => esc_html__( 'Enter the tags slugs seperated by a "comma"', 'multidirectory-addon' ),
				'type'          => Controls_Manager::TEXT,
				'label_block'   => true,
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		// Vars
		$posts_per_page = $settings['count'];
		$order 			= $settings['order'];
		$orderby  		= $settings['orderby'];
		$include 		= $settings['include_categories'];
		$exclude 		= $settings['exclude_categories'];
		$tags           = $settings['include_tags'];

		$args = array(
			'posts_per_page' => $posts_per_page,
			'post_type'      => 'post',
			'order'          => $order,
			'orderby'        => $orderby
		);

		// Include category
		if ( ! empty( $include ) ) {

			// Sanitize category and convert to array
			$include = str_replace( ', ', ',', $include );
			$include = explode( ',', $include );

			// Add to query arg
			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $include,
				'operator' => 'IN',
			);

		}

		// Exclude category
		if ( ! empty( $exclude ) ) {

			// Sanitize category and convert to array
			$exclude = str_replace( ', ', ',', $exclude );
			$exclude = explode( ',', $exclude );

			// Add to query arg
			$args['tax_query'][] = array(
				'taxonomy' => 'category',
				'field'    => 'slug',
				'terms'    => $exclude,
				'operator' => 'NOT IN',
			);

		}

		// Include tag
		if ( ! empty( $tags ) ) {

			// Sanitize category and convert to array
			$tags = str_replace( ', ', ',', $tags );
			$tags = explode( ',', $tags );

			// Add to query arg
			$args['tax_query'][] = array(
				'taxonomy' => 'post_tag',
				'field'    => 'slug',
				'terms'    => $tags,
				'operator' => 'IN',
			);

		}

		// Build the WordPress query
		$blog = new \WP_Query( $args );

		// Output posts
		if ( $blog->have_posts() ) :

			// Wrapper classes
			$wrap_classes = array( 'posts', 'owl-carousel', 'owl-theme', 'post-carousel' );
			$wrap_classes = implode( ' ', $wrap_classes );
			?>

			<div class="<?php echo esc_attr( $wrap_classes ); ?>">

				<?php

				// Start loop
				while ( $blog->have_posts() ) : $blog->the_post(); ?>

					<?php get_template_part( 'partials/elementor/carousel' ); ?>

				<?php
				// End entry loop
				endwhile; ?>

			</div><!-- .posts -->

			<?php
			// Reset the post data to prevent conflicts with WP globals
			wp_reset_postdata();

		else : ?>

			<?php get_template_part( 'partials/content/content', 'none' ); ?>

		<?php endif; ?>

	<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new Multidirectory_Addon_Widget_Post_Carousel() );
