<?php
/**
 * Header panel
 */
Kirki::add_panel( 'header', array(
	'title'          => esc_attr__( 'Header', 'multidirectory' ),
	'description'    => esc_attr__( 'Customize the header area of the theme.', 'multidirectory' ),
	'priority'       => 140,
) );

/**
 * Header section
 */
Kirki::add_section( 'header_settings', array(
	'title'          => esc_attr__( 'General', 'multidirectory' ),
	'priority'       => 1,
	'panel'          => 'header'
) );

/**
 * Header style
 */
Kirki::add_field( 'multidirectory_options', array(
	'type'        => 'select',
	'settings'    => 'header_style',
	'label'       => esc_attr__( 'Style', 'multidirectory' ),
	'section'     => 'header_settings',
	'default'     => 'default',
	'multiple'    => 1,
	'choices'     => array(
		'default' => esc_attr__( 'Default', 'multidirectory' ),
		'custom'  => esc_attr__( 'Custom Header', 'multidirectory' )
	),
) );

/**
 * Header custom
 */
Kirki::add_field( 'multidirectory_options', array(
	'type'        => 'select',
	'settings'    => 'header_template',
	'label'       => esc_attr__( 'Select Template', 'multidirectory' ),
	'description' => esc_attr__( 'Choose a template created in Appearance > My Library.', 'multidirectory' ),
	'section'     => 'header_settings',
	'default'     => '0',
	'multiple'    => 1,
	'choices'     => multidirectory_library( 'library' ),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'custom',
		),
	),
) );

/**
 * Height
 */
Kirki::add_field( 'multidirectory_options', array(
	'type'        => 'slider',
	'settings'    => 'header_height',
	'label'       => esc_attr__( 'Height', 'multidirectory' ),
	'description' => esc_attr__( 'Control the height of the header.', 'multidirectory' ),
	'section'     => 'header_settings',
	'default'     => '8',
	'choices'     => array(
		'min'  => '8',
		'max'  => '20',
		'step' => '1',
	),
	'output'      => array(
		array(
			'element'  => '.site-header .container',
			'property' => 'min-height',
			'units'    => 'rem',
			'exclude'  => array( '8' ),
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => '.site-header .container',
			'property' => 'min-height',
			'function' => 'css',
			'units'    => 'rem',
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
		array(
			'setting'  => 'header_variation',
			'operator' => '==',
			'value'    => 'variation-one',
		),
	),
) );

/**
 * Background color
 */
Kirki::add_field( 'multidirectory_options', array(
	'type'        => 'color',
	'settings'    => 'header_bg',
	'label'       => esc_attr__( 'Background Color', 'multidirectory' ),
	'section'     => 'header_settings',
	'default'     => '#ffffff',
	'choices'     => array(
		'alpha' => true,
	),
	'output'      => array(
		array(
			'element'  => '.site-header',
			'property' => 'background-color',
			'exclude'  => array( '#ffffff' ),
		),
	),
	'transport'   => 'postMessage',
	'js_vars'     => array(
		array(
			'element'  => '.site-header',
			'property' => 'background-color',
			'function' => 'css',
		),
	),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Add Listing text
 */
Kirki::add_field( 'multidirectory_options', array(
	'type'     => 'text',
	'settings' => 'header_listing_txt',
	'label'    => esc_attr__( 'Listing Button Text', 'multidirectory' ),
	'section'  => 'header_settings',
	'default'  => esc_attr__( 'Add Listing', 'multidirectory' ),
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );

/**
 * Listing url
 */
Kirki::add_field( 'multidirectory_options', array(
	'type'     => 'url',
	'settings' => 'header_listing_url',
	'label'    => esc_attr__( 'Listing Button URL', 'multidirectory' ),
	'section'  => 'header_settings',
	'default'  => '#',
	'required'    => array(
		array(
			'setting'  => 'header_style',
			'operator' => '==',
			'value'    => 'default',
		),
	),
) );
